@@ -45,10 +45,7 @@ window.tabBar = {
     var tabEl = tabBar.getTab(tabId)
     var webview = webviews.get(tabId)
 
-    var currentURL = urlParser.getDisplayURL(tabs.get(tabId).url)
-    if (currentURL === 'about:blank') {
-      currentURL = ''
-    }
+    var currentURL = urlParser.getSourceURL(tabs.get(tabId).url)
 
     document.body.classList.add('is-edit-mode')
     tabEl.classList.add('selected')
@@ -97,10 +94,14 @@ window.tabBar = {
 
     var tabTitle = tabData.title || l('newTabLabel')
 
-    tabEl.title = tabTitle
     var titleEl = tabEl.querySelector('.tab-view-contents .title')
     titleEl.textContent = tabTitle
 
+    tabEl.title = tabTitle
+    if (tabData.private) {
+      tabEl.title += ' (' + l('privateTab') + ')'
+    }
+
     var secIcon = tabEl.getElementsByClassName('icon-tab-not-secure')[0]
     if (tabData.secure === false) {
       secIcon.hidden = false
@@ -130,7 +131,11 @@ window.tabBar = {
     var tabEl = document.createElement('div')
     tabEl.className = 'tab-item'
     tabEl.setAttribute('data-tab', data.id)
+
     tabEl.title = tabTitle
+    if (data.private) {
+      tabEl.title += ' (' + l('privateTab') + ')'
+    }
 
     var ec = document.createElement('div')
     ec.className = 'tab-edit-contents'
@@ -173,8 +178,6 @@ window.tabBar = {
       var pbIcon = document.createElement('i')
       pbIcon.className = 'fa fa-eye-slash icon-tab-is-private tab-info-icon'
       iconArea.appendChild(pbIcon)
-
-      vc.setAttribute('title', l('privateTab'))
     }
 
     var secIcon = document.createElement('i')
@@ -319,3 +322,9 @@ webviews.bindEvent('did-stop-loading', function () {
   var tabId = webviews.getTabFromContents(this)
   progressBar.update(tabBar.getTab(tabId).querySelector('.progress-bar'), 'finish')
 })
+
+tasks.on('tab-updated', function (id, key) {
+  if (key === 'title' || key === 'secure' || key === 'url') {
+    tabBar.rerenderTab(id)
+  }
+})
