@@ -75,13 +75,13 @@ function getColorFromImage (image) {
   // dim the colors late at night or early in the morning, or when dark mode is enabled
   let colorChange = 1
   if (hours > 20) {
-    colorChange -= 0.015 * Math.pow(2.75, hours - 20)
+    colorChange = 1.01 / (1 + 0.9 * Math.pow(Math.E, 1.5 * (hours - 22.75)))
   } else if (hours < 6.5) {
-    colorChange -= -0.15 * Math.pow(1.36, hours) + 1.15
+    colorChange = 1.04 / (1 + 0.9 * Math.pow(Math.E, -2 * (hours - 5)))
   }
 
   if (window.isDarkMode) {
-    colorChange = Math.min(colorChange, 0.58)
+    colorChange = Math.min(colorChange, 0.6)
   }
 
   res[0] = Math.round(res[0] * colorChange)
@@ -160,8 +160,10 @@ const tabColor = {
 
     // theme changes can affect the tab colors
     window.addEventListener('themechange', function (e) {
-      tabColor.refresh()
+      tabColor.updateColors()
     })
+
+    tasks.on('tab-selected', this.updateColors)
   },
   updateFromImage: function (favicons, tabId) {
     // private tabs always use a special color, we don't need to get the icon
@@ -183,7 +185,7 @@ const tabColor = {
         })
 
         if (tabId === tabs.getSelected()) {
-          tabColor.refresh()
+          tabColor.updateColors()
         }
       }
       colorExtractorImage.src = favicons[0]
@@ -191,7 +193,7 @@ const tabColor = {
       timeout: 1000
     })
   },
-  refresh: function () {
+  updateColors: function () {
     const tab = tabs.get(tabs.getSelected())
 
     // private tabs have their own color scheme
