@@ -159,6 +159,32 @@ registerCustomBang({
   }
 })
 
+registerCustomBang({
+  phrase: '!closetask',
+  snippet: l('closeTask'),
+  isAction: false,
+  fn: function (text) {
+    var currentTask = tasks.getSelected()
+    var taskToClose
+
+    if (text) {
+      taskToClose = getTaskByNameOrNumber(text)
+    } else {
+      taskToClose = tasks.getSelected()
+    }
+
+    if (taskToClose) {
+      browserUI.closeTask(taskToClose.id)
+      if (currentTask.id === taskToClose.id) {
+        taskOverlay.show()
+        setTimeout(function () {
+          taskOverlay.hide()
+        }, 600)
+      }
+    }
+  }
+})
+
 registerCustomBang({
   phrase: '!bookmarks',
   snippet: l('searchBookmarks'),
@@ -182,11 +208,12 @@ registerCustomBang({
         container.appendChild(searchbarUtils.createItem({
           title: result.title,
           icon: 'fa-star',
-          secondaryText: result.url,
+          secondaryText: urlParser.getSourceURL(result.url),
           url: result.url,
           delete: function () {
             places.deleteHistory(result.url)
-          }
+          },
+          showDeleteButton: true
         }))
       })
     }, {searchBookmarks: true, limit: (text ? 100 : Infinity)})
@@ -228,11 +255,12 @@ registerCustomBang({
         }
         container.appendChild(searchbarUtils.createItem({
           title: result.title,
-          secondaryText: result.url,
+          secondaryText: urlParser.getSourceURL(result.url),
           url: result.url,
           delete: function () {
             places.deleteHistory(result.url)
-          }
+          },
+          showDeleteButton: true
         }))
       })
     }, {limit: Infinity})
