@@ -1,12 +1,65 @@
+/* Back button */
+
 var backbutton = document.getElementById('backtoarticle')
 var articleURL = new URLSearchParams(window.location.search).get('url')
 
 backbutton.addEventListener('click', function (e) {
+  // there's likely a problem with reader view on this page, so don't auto-redirect to it in the future
+  readerDecision.setURLStatus(articleURL, false)
+
   window.location = articleURL
 })
 
+/* Auto redirect banner */
+var autoRedirectBanner = document.getElementById('auto-redirect-banner')
+var autoRedirectYes = document.getElementById('auto-redirect-yes')
+var autoRedirectNo = document.getElementById('auto-redirect-no')
+
+if (readerDecision.getDomainStatus(articleURL) === undefined && readerDecision.getSameDomainStatuses(articleURL).length > 0) {
+  autoRedirectBanner.hidden = false
+}
+
+autoRedirectYes.addEventListener('click', function () {
+  readerDecision.setDomainStatus(articleURL, true)
+  autoRedirectBanner.hidden = true
+  autoReaderCheckbox.checked = true
+})
+autoRedirectNo.addEventListener('click', function () {
+  readerDecision.setDomainStatus(articleURL, false)
+  autoRedirectBanner.hidden = false
+})
+
+/* Settings */
+
+var settingsButton = document.getElementById('settings-button')
+var settingsDropdown = document.getElementById('settings-dropdown')
+
+settingsButton.addEventListener('click', function () {
+  settingsDropdown.hidden = !settingsDropdown.hidden
+})
+
+window.addEventListener('blur', function () {
+  if (document.activeElement.tagName === 'IFRAME') {
+    // clicked on reader frame
+    settingsDropdown.hidden = true
+  }
+})
+
+document.addEventListener('click', function (e) {
+  if (!settingsDropdown.contains(e.target) && e.target !== settingsButton) {
+    settingsDropdown.hidden = true
+  }
+})
+
+var autoReaderCheckbox = document.getElementById('auto-reader-checkbox')
+autoReaderCheckbox.checked = (readerDecision.getDomainStatus(articleURL) === true)
+autoReaderCheckbox.addEventListener('change', function () {
+  readerDecision.setDomainStatus(articleURL, this.checked)
+  autoRedirectBanner.hidden = true
+})
+
 function startReaderView (article) {
-  var readerContent = "<link rel='stylesheet' href='readerView.css'>"
+  var readerContent = "<link rel='stylesheet' href='readerContent.css'>"
 
   if (!article) { // we couln't parse an article
     readerContent += "<div class='reader-main'><em>No article found.</em></div>"
@@ -36,10 +89,7 @@ function startReaderView (article) {
 
   // resize the frame once the page has loaded and the content height can be determined
   rframe.onload = function () {
-    if (window.isDarkMode) {
-      rframe.contentDocument.body.classList.add('dark-mode')
-    }
-
+    setReaderTheme()
     requestAnimationFrame(function () {
       rframe.height = rframe.contentDocument.body.querySelector('.reader-main').scrollHeight + 'px'
       requestAnimationFrame(function () {
@@ -62,7 +112,7 @@ function startReaderView (article) {
 
 function processArticle (data) {
   var parserframe = document.createElement('iframe')
-  parserframe.className = 'temporary-iframe'
+  parserframe.className = 'temporary-frame'
   parserframe.sandbox = 'allow-same-origin'
   document.body.appendChild(parserframe)
 
@@ -104,6 +154,11 @@ function processArticle (data) {
     console.log(article)
     startReaderView(article)
 
+    if (article) {
+      // mark this page as readerable so that auto-redirect can happen faster on future visits
+      readerDecision.setURLStatus(articleURL, true)
+    }
+
     document.body.removeChild(parserframe)
 
     saveArticle(articleURL, article, {
@@ -136,29 +191,6 @@ fetch(articleURL, {
     })
   })
 
-/* update appearance when theme changes */
-
-var iconElement = document.getElementById('page-icon')
-function setPageIcon () {
-  if (window.isDarkMode) {
-    iconElement.href = 'blackFavicon.png'
-  } else {
-    iconElement.href = 'whiteFavicon.png'
-  }
-}
-setPageIcon()
-
-window.addEventListener('themechange', function () {
-  if (window.rframe) {
-    if (window.isDarkMode) {
-      rframe.contentDocument.body.classList.add('dark-mode')
-    } else {
-      rframe.contentDocument.body.classList.remove('dark-mode')
-    }
-  }
-  setPageIcon()
-})
-
 function printArticle () {
   rframe.contentWindow.print()
 }
